@@ -38,7 +38,11 @@ where
                                 // his parent is a BranchingOut . Since more than 1 event is
                                 // associated to the node in xml (as transferBack+leaf)
                                 // and only one is  associated to the node in the structure
-                                // ( here leaf), this is useful for drawing the transfer.
+    pub go_left: usize,                            // ( here leaf), this is useful for drawing the transfer.
+    pub go_right: usize,
+    pub fixed: bool,
+    pub transfers: Vec<usize>,      // gene nodes associes (dans le cas d'arbre d'espece)
+
 }
 impl<T> Noeud<T>
 where
@@ -63,6 +67,10 @@ where
             nbg: 0,
             nodes: vec![],
             is_a_transfert:false,
+            go_left: 0,
+            go_right: 0,
+            fixed:false,
+            transfers: vec![],
         }
     }
     /// Set node event
@@ -250,6 +258,8 @@ pub struct Options{
     pub thickness_flag: bool,
     pub thickness_thresh: usize,
     pub thickness_gene: usize,
+    pub thickness_disp_score:bool,
+    pub optimisation:bool,
 }
 impl Options {
     pub fn new() -> Self {
@@ -269,6 +279,9 @@ impl Options {
             thickness_flag:false,
             thickness_thresh:0,
             thickness_gene:0,
+            thickness_disp_score:false,
+            optimisation:false,
+
         }
     }
 }
